==> mythplugins_0.18.1.orig.tar.gz: mythplugins-0.18.1/mythnews/i18n/mythnews_sv.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MythNews</name>
    <message>
        <source>Updated</source>
        <translation>Uppdaterad</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
</context>
<context>
    <name>MythNewsConfig</name>
    <message>
        <source>Press MENU to set the update frequency.</source>
        <translation>Tryck på MENY för att ställa in uppdateringsfrekvensen.</translation>
    </message>
    <message>
        <source>Set update frequency by using the up/down arrows.
The minimum allowed value is 30 Minutes.</source>
        <translation>Ställ in uppdateringsfrekvensen med knapparna upp och ner.
Minsta tillåtna värdet är 30 minuter.</translation>
    </message>
    <message>
        <source>Press MENU to return to feed selection.</source>
        <translation>Tryck på MENY för att återvända till val av nyhetskällor.</translation>
    </message>
</context>
<context>
    <name>NewsSite</name>
    <message>
        <source>Failed to retrieve news</source>
        <translation>Misslyckades med att hämta nyheter</translation>
    </message>
    <message>
        <source>Retrieve Failed. </source>
        <translation>Mottagning misslyckades.</translation>
    </message>
    <message>
        <source>No Cached News</source>
        <translation>Inga lagrade nyheter</translation>
    </message>
    <message>
        <source>Failed to read downloaded file</source>
        <translation>Misslyckades med att läsa den nerladdade filen</translation>
    </message>
    <message>
        <source>Showing Cached News</source>
        <translation>Visar lagrade nyheter</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Minutes</source>
        <translation>Minuter</translation>
    </message>
</context>
</TS>

==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythnews/i18n/mythnews_sv.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MythNews</name>
    <message>
        <source>Updated</source>
        <translation>Uppdaterad</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>Edit Site Details</source>
        <translation>Redigera platsdetaljer</translation>
    </message>
    <message>
        <source>Enter Site Details</source>
        <translation>Ange platsdetaljer</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Edit News Site</source>
        <translation>Redigera nyhetsplats</translation>
    </message>
    <message>
        <source>Add News Site</source>
        <translation>Lägg till nyhetsplats</translation>
    </message>
    <message>
        <source>Delete News Site</source>
        <translation>Ta bort nyhetsplats</translation>
    </message>
</context>
<context>
    <name>MythNewsConfig</name>
    <message>
        <source>Press MENU to set the update frequency.</source>
        <translation>Tryck på MENY för att ställa in uppdateringsfrekvensen.</translation>
    </message>
    <message>
        <source>Set update frequency by using the up/down arrows.
The minimum allowed value is 30 Minutes.</source>
        <translation>Ställ in uppdateringsfrekvensen med knapparna upp och ner.
Minsta tillåtna värdet är 30 minuter.</translation>
    </message>
    <message>
        <source>Press MENU to return to feed selection.</source>
        <translation>Tryck på MENY för att återvända till val av nyhetskällor.</translation>
    </message>
</context>
<context>
    <name>NewsSite</name>
    <message>
        <source>Failed to retrieve news</source>
        <translation>Misslyckades med att hämta nyheter</translation>
    </message>
    <message>
        <source>Retrieve Failed. </source>
        <translation>Mottagning misslyckades.</translation>
    </message>
    <message>
        <source>No Cached News</source>
        <translation>Inga lagrade nyheter</translation>
    </message>
    <message>
        <source>Failed to read downloaded file</source>
        <translation>Misslyckades med att läsa den nerladdade filen</translation>
    </message>
    <message>
        <source>Showing Cached News</source>
        <translation>Visar lagrade nyheter</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>MythNews</source>
        <translation>MythNews</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this news site

%1</source>
        <translation>Är du säker på att du vill ta bort denna nyhetsplats

%1</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Minutes</source>
        <translation>Minuter</translation>
    </message>
</context>
</TS>
